@@ -32,24 +32,24 @@
 #include "macros.h"
 #include "unicodeset.h"
 
-DECLARE_CONSTANTS_TYPE(UProperty);
-DECLARE_CONSTANTS_TYPE(UCharDirection);
-DECLARE_CONSTANTS_TYPE(UCharCategory);
-DECLARE_CONSTANTS_TYPE(UBlockCode);
-DECLARE_CONSTANTS_TYPE(UCharNameChoice);
-DECLARE_CONSTANTS_TYPE(UPropertyNameChoice);
-DECLARE_CONSTANTS_TYPE(UWordBreakValues);
-DECLARE_CONSTANTS_TYPE(UJoiningGroup);
-DECLARE_CONSTANTS_TYPE(ULineBreak);
-DECLARE_CONSTANTS_TYPE(UGraphemeClusterBreak);
-DECLARE_CONSTANTS_TYPE(UHangulSyllableType);
+DECLARE_CONSTANTS_TYPE(UProperty)
+DECLARE_CONSTANTS_TYPE(UCharDirection)
+DECLARE_CONSTANTS_TYPE(UCharCategory)
+DECLARE_CONSTANTS_TYPE(UBlockCode)
+DECLARE_CONSTANTS_TYPE(UCharNameChoice)
+DECLARE_CONSTANTS_TYPE(UPropertyNameChoice)
+DECLARE_CONSTANTS_TYPE(UWordBreakValues)
+DECLARE_CONSTANTS_TYPE(UJoiningGroup)
+DECLARE_CONSTANTS_TYPE(ULineBreak)
+DECLARE_CONSTANTS_TYPE(UGraphemeClusterBreak)
+DECLARE_CONSTANTS_TYPE(UHangulSyllableType)
 #if U_ICU_VERSION_HEX >= VERSION_HEX(52, 0, 0)
-DECLARE_CONSTANTS_TYPE(UBidiPairedBracketType);
+DECLARE_CONSTANTS_TYPE(UBidiPairedBracketType)
 #endif
 #if U_ICU_VERSION_HEX >= VERSION_HEX(63, 0, 0)
-DECLARE_CONSTANTS_TYPE(UIndicPositionalCategory);
-DECLARE_CONSTANTS_TYPE(UIndicSyllabicCategory);
-DECLARE_CONSTANTS_TYPE(UVerticalOrientation);
+DECLARE_CONSTANTS_TYPE(UIndicPositionalCategory)
+DECLARE_CONSTANTS_TYPE(UIndicSyllabicCategory)
+DECLARE_CONSTANTS_TYPE(UVerticalOrientation)
 #endif
 
 
@@ -112,6 +112,10 @@ static PyObject *t_char_charFromName(PyTypeObject *type, PyObject *args);
 static PyObject *t_char_enumCharNames(PyTypeObject *type, PyObject *args);
 static PyObject *t_char_getPropertyName(PyTypeObject *type, PyObject *args);
 static PyObject *t_char_getPropertyEnum(PyTypeObject *type, PyObject *arg);
+static PyObject *t_char_getPropertyValueName(PyTypeObject *type,
+                                             PyObject *args);
+static PyObject *t_char_getPropertyValueEnum(PyTypeObject *type,
+                                             PyObject *args);
 static PyObject *t_char_isIDStart(PyTypeObject *type, PyObject *arg);
 static PyObject *t_char_isIDPart(PyTypeObject *type, PyObject *arg);
 static PyObject *t_char_isIDIgnorable(PyTypeObject *type, PyObject *arg);
@@ -174,6 +178,8 @@ static PyMethodDef t_char_methods[] = {
     DECLARE_METHOD(t_char, enumCharNames, METH_VARARGS | METH_CLASS),
     DECLARE_METHOD(t_char, getPropertyName, METH_VARARGS | METH_CLASS),
     DECLARE_METHOD(t_char, getPropertyEnum, METH_O | METH_CLASS),
+    DECLARE_METHOD(t_char, getPropertyValueName, METH_VARARGS | METH_CLASS),
+    DECLARE_METHOD(t_char, getPropertyValueEnum, METH_VARARGS | METH_CLASS),
     DECLARE_METHOD(t_char, isIDStart, METH_O | METH_CLASS),
     DECLARE_METHOD(t_char, isIDPart, METH_O | METH_CLASS),
     DECLARE_METHOD(t_char, isIDIgnorable, METH_O | METH_CLASS),
@@ -196,7 +202,7 @@ static void t_char_dealloc(t_char *self)
     Py_TYPE(self)->tp_free((PyObject *) self);
 }
 
-DECLARE_STRUCT(Char, t_char, UNone, t_char_init, t_char_dealloc);
+DECLARE_STRUCT(Char, t_char, UNone, t_char_init, t_char_dealloc)
 
 /* Char */
 
@@ -702,14 +708,60 @@ static PyObject *t_char_getPropertyName(PyTypeObject *type, PyObject *args)
 
 static PyObject *t_char_getPropertyEnum(PyTypeObject *type, PyObject *arg)
 {
-    char *alias;
+    charsArg alias;
 
-    if (!parseArg(arg, "c", &alias))
+    if (!parseArg(arg, "n", &alias))
         return PyInt_FromLong(u_getPropertyEnum(alias));
 
     return PyErr_SetArgsError((PyObject *) type, "getPropertyEnum", arg);
 }
 
+static PyObject *t_char_getPropertyValueName(PyTypeObject *type, PyObject *args)
+{
+    UPropertyNameChoice choice = U_SHORT_PROPERTY_NAME;
+    int32_t value;
+    UProperty prop;
+    const char *result;
+
+    switch (PyTuple_Size(args)) {
+      case 2:
+        if (!parseArgs(args, "ii", &prop, &value))
+        {
+            result = u_getPropertyValueName(prop, value, choice);
+            if (result != NULL)
+                return PyString_FromString(result);
+            Py_RETURN_NONE;
+        }
+        break;
+      case 3:
+        if (!parseArgs(args, "iii", &prop, &value, &choice))
+        {
+            result = u_getPropertyValueName(prop, value, choice);
+            if (result != NULL)
+                return PyString_FromString(result);
+            Py_RETURN_NONE;
+        }
+        break;
+    }
+
+    return PyErr_SetArgsError((PyObject *) type, "getPropertyValueName", args);
+}
+
+static PyObject *t_char_getPropertyValueEnum(PyTypeObject *type, PyObject *args)
+{
+    UProperty prop;
+    charsArg alias;
+
+    switch (PyTuple_Size(args)) {
+      case 2:
+        if (!parseArgs(args, "in", &prop, &alias))
+            return PyInt_FromLong(u_getPropertyValueEnum(prop, alias));
+        break;
+    }
+
+    return PyErr_SetArgsError((PyObject *) type, "getPropertyValueEnum", args);
+}
+
 static PyObject *t_char_fn(uchar32_char_fn fn, const char *name,
                            PyTypeObject *type, PyObject *arg)
 {
@@ -1419,6 +1471,16 @@ void _init_char(PyObject *m)
     INSTALL_ENUM(UBlockCode, "SYMBOLS_AND_PICTOGRAPHS_EXTENDED_A", UBLOCK_SYMBOLS_AND_PICTOGRAPHS_EXTENDED_A);
     INSTALL_ENUM(UBlockCode, "TAMIL_SUPPLEMENT", UBLOCK_TAMIL_SUPPLEMENT);
     INSTALL_ENUM(UBlockCode, "WANCHO", UBLOCK_WANCHO);
+#endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(66, 0, 0)
+    INSTALL_ENUM(UBlockCode, "CHORASMIAN", UBLOCK_CHORASMIAN);
+    INSTALL_ENUM(UBlockCode, "CJK_UNIFIED_IDEOGRAPHS_EXTENSION_G", UBLOCK_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_G);
+    INSTALL_ENUM(UBlockCode, "DIVES_AKURU", UBLOCK_DIVES_AKURU);
+    INSTALL_ENUM(UBlockCode, "KHITAN_SMALL_SCRIPT", UBLOCK_KHITAN_SMALL_SCRIPT);
+    INSTALL_ENUM(UBlockCode, "LISU_SUPPLEMENT", UBLOCK_LISU_SUPPLEMENT);
+    INSTALL_ENUM(UBlockCode, "SYMBOLS_FOR_LEGACY_COMPUTING", UBLOCK_SYMBOLS_FOR_LEGACY_COMPUTING);
+    INSTALL_ENUM(UBlockCode, "TANGUT_SUPPLEMENT", UBLOCK_TANGUT_SUPPLEMENT);
+    INSTALL_ENUM(UBlockCode, "YEZIDI", UBLOCK_YEZIDI);
 #endif
     INSTALL_ENUM(UBlockCode, "INVALID_CODE", UBLOCK_INVALID_CODE);
 
@@ -1453,6 +1515,9 @@ void _init_char(PyObject *m)
     INSTALL_ENUM(UIndicPositionalCategory, "TOP_AND_LEFT_AND_RIGHT", U_INPC_TOP_AND_LEFT_AND_RIGHT);
     INSTALL_ENUM(UIndicPositionalCategory, "TOP_AND_RIGHT", U_INPC_TOP_AND_RIGHT);
     INSTALL_ENUM(UIndicPositionalCategory, "VISUAL_ORDER_LEFT", U_INPC_VISUAL_ORDER_LEFT);
+#if U_ICU_VERSION_HEX >= VERSION_HEX(66, 0, 0)
+    INSTALL_ENUM(UIndicPositionalCategory, "TOP_AND_BOTTOM_AND_LEFT", U_INPC_TOP_AND_BOTTOM_AND_LEFT);
+#endif
 
     INSTALL_ENUM(UIndicSyllabicCategory, "OTHER", U_INSC_OTHER);
     INSTALL_ENUM(UIndicSyllabicCategory, "AVAGRAHA", U_INSC_AVAGRAHA);
@@ -1495,7 +1560,7 @@ void _init_char(PyObject *m)
     INSTALL_ENUM(UVerticalOrientation, "TRANSFORMED_ROTATED", U_VO_TRANSFORMED_ROTATED);
     INSTALL_ENUM(UVerticalOrientation, "TRANSFORMED_UPRIGHT", U_VO_TRANSFORMED_UPRIGHT);
     INSTALL_ENUM(UVerticalOrientation, "UPRIGHT", U_VO_UPRIGHT);
-#endif
+#endif  // ICU >= 63
 
 #if U_ICU_VERSION_HEX >= 0x04000000
     INSTALL_ENUM(UWordBreakValues, "CR", U_WB_CR);
