@@ -237,7 +237,13 @@ typedef intintobjargproc ssizessizeobjargproc;
 #include <unicode/stringoptions.h>
 #endif
 
+#if U_ICU_VERSION_HEX >= VERSION_HEX(63, 0, 0)
+#include <unicode/numberrangeformatter.h>
+#include <unicode/ulistformatter.h>
+#endif
+
 #if U_ICU_VERSION_HEX >= VERSION_HEX(64, 0, 0)
+#include <unicode/formattedvalue.h>
 #include <unicode/localebuilder.h>
 #endif
 
@@ -420,6 +426,11 @@ int _parseArgs(PyObject **args, int count, const char *types, va_list list);
 
 #else
 
+#ifdef __clang__
+#pragma clang diagnostic ignored "-Wvariadic-macros"
+#pragma clang diagnostic ignored "-Wgnu-zero-variadic-macro-arguments"
+#endif
+
 #define parseArgs(args, types, rest...) \
     _parseArgs(((PyTupleObject *)(args))->ob_item, \
                (int) PyObject_Size(args), types, ##rest)
