@@ -6,10 +6,10 @@
  * to deal in the Software without restriction, including without limitation
  * the rights to use, copy, modify, merge, publish, distribute, sublicense,
  * and/or sell copies of the Software, and to permit persons to whom the
- * Software is furnished to do so, subject to the following conditions: 
+ * Software is furnished to do so, subject to the following conditions:
  *
  * The above copyright notice and this permission notice shall be included
- * in all copies or substantial portions of the Software. 
+ * in all copies or substantial portions of the Software.
  *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
  * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
@@ -32,27 +32,35 @@
 #include "dateformat.h"
 #include "macros.h"
 
-DECLARE_CONSTANTS_TYPE(UDateTimePatternConflict);
-DECLARE_CONSTANTS_TYPE(UDateTimePatternField);
+DECLARE_CONSTANTS_TYPE(UDateTimePatternConflict)
+DECLARE_CONSTANTS_TYPE(UDateTimePatternField)
 
 #if U_ICU_VERSION_HEX >= 0x04040000
-DECLARE_CONSTANTS_TYPE(UDateTimePatternMatchOptions);
+DECLARE_CONSTANTS_TYPE(UDateTimePatternMatchOptions)
 #endif
 
 #if U_ICU_VERSION_HEX >= VERSION_HEX(54, 0, 0)
-DECLARE_CONSTANTS_TYPE(UDateRelativeDateTimeFormatterStyle);
+DECLARE_CONSTANTS_TYPE(UDateRelativeDateTimeFormatterStyle)
 #endif
 
 #if U_ICU_VERSION_HEX >= VERSION_HEX(51, 0, 0)
-DECLARE_CONSTANTS_TYPE(UDisplayContext);
-DECLARE_CONSTANTS_TYPE(UDisplayContextType);
+DECLARE_CONSTANTS_TYPE(UDisplayContext)
+DECLARE_CONSTANTS_TYPE(UDisplayContextType)
 #endif
 
 #if U_ICU_VERSION_HEX >= VERSION_HEX(53, 0, 0)
-DECLARE_CONSTANTS_TYPE(UDateDirection);
-DECLARE_CONSTANTS_TYPE(UDateAbsoluteUnit);
-DECLARE_CONSTANTS_TYPE(UDateRelativeUnit);
-DECLARE_CONSTANTS_TYPE(UDateFormatBooleanAttribute);
+DECLARE_CONSTANTS_TYPE(UDateDirection)
+DECLARE_CONSTANTS_TYPE(UDateAbsoluteUnit)
+DECLARE_CONSTANTS_TYPE(UDateRelativeUnit)
+DECLARE_CONSTANTS_TYPE(UDateFormatBooleanAttribute)
+#endif
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(57, 0, 0)
+DECLARE_CONSTANTS_TYPE(URelativeDateTimeUnit)
+#endif
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(64, 0, 0)
+DECLARE_CONSTANTS_TYPE(URelativeDateTimeFormatterField)
 #endif
 
 /* DateFormatSymbols */
@@ -108,7 +116,7 @@ static PyMethodDef t_dateformatsymbols_methods[] = {
 };
 
 DECLARE_TYPE(DateFormatSymbols, t_dateformatsymbols, UObject,
-             DateFormatSymbols, t_dateformatsymbols_init, NULL);
+             DateFormatSymbols, t_dateformatsymbols_init, NULL)
 
 /* DateFormat */
 
@@ -169,7 +177,7 @@ static PyMethodDef t_dateformat_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(DateFormat, t_dateformat, Format, DateFormat, abstract_init, NULL);
+DECLARE_TYPE(DateFormat, t_dateformat, Format, DateFormat, abstract_init, NULL)
 
 /* SimpleDateFormat */
 
@@ -207,7 +215,7 @@ static PyMethodDef t_simpledateformat_methods[] = {
 };
 
 DECLARE_TYPE(SimpleDateFormat, t_simpledateformat, DateFormat,
-             SimpleDateFormat, t_simpledateformat_init, NULL);
+             SimpleDateFormat, t_simpledateformat_init, NULL)
 
 PyObject *wrap_DateFormat(DateFormat *format)
 {
@@ -293,7 +301,7 @@ static PyMethodDef t_datetimepatterngenerator_methods[] = {
 };
 
 DECLARE_TYPE(DateTimePatternGenerator, t_datetimepatterngenerator,
-             UObject, DateTimePatternGenerator, abstract_init, NULL);
+             UObject, DateTimePatternGenerator, abstract_init, NULL)
 
 #if U_ICU_VERSION_HEX >= 0x04000000
 
@@ -316,7 +324,7 @@ static PyMethodDef t_dateinterval_methods[] = {
 };
 
 DECLARE_TYPE(DateInterval, t_dateinterval, UObject, DateInterval,
-             t_dateinterval_init, NULL);
+             t_dateinterval_init, NULL)
 
 /* DateIntervalInfo */
 
@@ -345,7 +353,7 @@ static PyMethodDef t_dateintervalinfo_methods[] = {
 };
 
 DECLARE_TYPE(DateIntervalInfo, t_dateintervalinfo, UObject, DateIntervalInfo,
-             t_dateintervalinfo_init, NULL);
+             t_dateintervalinfo_init, NULL)
 
 /* DateIntervalFormat */
 
@@ -365,6 +373,10 @@ static PyObject *t_dateintervalformat_parseObject(t_dateintervalformat *self,
                                                   PyObject *args);
 static PyObject *t_dateintervalformat_createInstance(PyTypeObject *type,
                                                      PyObject *args);
+#if U_ICU_VERSION_HEX >= VERSION_HEX(64, 0, 0)
+static PyObject *t_dateintervalformat_formatToValue(t_dateintervalformat *self,
+                                                     PyObject *args);
+#endif
 
 static PyMethodDef t_dateintervalformat_methods[] = {
     DECLARE_METHOD(t_dateintervalformat, format, METH_VARARGS),
@@ -373,11 +385,14 @@ static PyMethodDef t_dateintervalformat_methods[] = {
     DECLARE_METHOD(t_dateintervalformat, getDateFormat, METH_NOARGS),
     DECLARE_METHOD(t_dateintervalformat, parseObject, METH_VARARGS),
     DECLARE_METHOD(t_dateintervalformat, createInstance, METH_VARARGS | METH_CLASS),
+#if U_ICU_VERSION_HEX >= VERSION_HEX(64, 0, 0)
+    DECLARE_METHOD(t_dateintervalformat, formatToValue, METH_VARARGS),
+#endif
     { NULL, NULL, 0, NULL }
 };
 
 DECLARE_TYPE(DateIntervalFormat, t_dateintervalformat, Format,
-             DateIntervalFormat, abstract_init, NULL);
+             DateIntervalFormat, abstract_init, NULL)
 
 #endif
 
@@ -394,26 +409,83 @@ static int t_relativedatetimeformatter_init(t_relativedatetimeformatter *self,
                                             PyObject *args, PyObject *kwds);
 static PyObject *t_relativedatetimeformatter_format(
     t_relativedatetimeformatter *self, PyObject *args);
+#if U_ICU_VERSION_HEX >= VERSION_HEX(57, 0, 0)
+static PyObject *t_relativedatetimeformatter_formatNumeric(
+    t_relativedatetimeformatter *self, PyObject *args);
+#endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(64, 0, 0)
+static PyObject *t_relativedatetimeformatter_formatToValue(
+    t_relativedatetimeformatter *self, PyObject *args);
+static PyObject *t_relativedatetimeformatter_formatNumericToValue(
+    t_relativedatetimeformatter *self, PyObject *args);
+#endif
 static PyObject *t_relativedatetimeformatter_combineDateAndTime(
     t_relativedatetimeformatter *self, PyObject *args);
 static PyObject *t_relativedatetimeformatter_getNumberFormat(
     t_relativedatetimeformatter *self);
+#if U_ICU_VERSION_HEX >= VERSION_HEX(54, 0, 0)
 static PyObject *t_relativedatetimeformatter_getCapitalizationContext(
     t_relativedatetimeformatter *self);
 static PyObject *t_relativedatetimeformatter_getFormatStyle(
     t_relativedatetimeformatter *self);
+#endif
 
 static PyMethodDef t_relativedatetimeformatter_methods[] = {
     DECLARE_METHOD(t_relativedatetimeformatter, format, METH_VARARGS),
+#if U_ICU_VERSION_HEX >= VERSION_HEX(57, 0, 0)
+    DECLARE_METHOD(t_relativedatetimeformatter, formatNumeric, METH_VARARGS),
+#endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(64, 0, 0)
+    DECLARE_METHOD(t_relativedatetimeformatter, formatToValue, METH_VARARGS),
+    DECLARE_METHOD(t_relativedatetimeformatter, formatNumericToValue, METH_VARARGS),
+#endif
     DECLARE_METHOD(t_relativedatetimeformatter, combineDateAndTime, METH_VARARGS),
     DECLARE_METHOD(t_relativedatetimeformatter, getNumberFormat, METH_NOARGS),
+#if U_ICU_VERSION_HEX >= VERSION_HEX(54, 0, 0)
     DECLARE_METHOD(t_relativedatetimeformatter, getCapitalizationContext, METH_NOARGS),
     DECLARE_METHOD(t_relativedatetimeformatter, getFormatStyle, METH_NOARGS),
+#endif
     { NULL, NULL, 0, NULL }
 };
 
 DECLARE_TYPE(RelativeDateTimeFormatter, t_relativedatetimeformatter, UObject,
-             RelativeDateTimeFormatter, t_relativedatetimeformatter_init, NULL);
+             RelativeDateTimeFormatter, t_relativedatetimeformatter_init, NULL)
+
+#endif
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(64, 0, 0)
+
+/* FormattedDateInterval */
+
+class t_formatteddateinterval : public _wrapper {
+public:
+    FormattedDateInterval *object;
+    ConstrainedFieldPosition cfp;  // for iterator on t_formattedvalue
+};
+
+static PyMethodDef t_formatteddateinterval_methods[] = {
+    { NULL, NULL, 0, NULL }
+};
+
+DECLARE_BY_VALUE_TYPE(
+    FormattedDateInterval, t_formatteddateinterval, FormattedValue,
+    FormattedDateInterval, abstract_init)
+
+/* FormattedRelativeDateTime */
+
+class t_formattedrelativedatetime : public _wrapper {
+public:
+    FormattedRelativeDateTime *object;
+    ConstrainedFieldPosition cfp;  // for iterator on t_formattedvalue
+};
+
+static PyMethodDef t_formattedrelativedatetime_methods[] = {
+    { NULL, NULL, 0, NULL }
+};
+
+DECLARE_BY_VALUE_TYPE(
+    FormattedRelativeDateTime, t_formattedrelativedatetime, FormattedValue,
+    FormattedRelativeDateTime, abstract_init)
 
 #endif
 
@@ -466,7 +538,7 @@ static int t_dateformatsymbols_init(t_dateformatsymbols *self,
         PyErr_SetArgsError((PyObject *) self, "__init__", args);
         return -1;
     }
-        
+
     if (self->object)
         return 0;
 
@@ -477,7 +549,7 @@ static PyObject *fromUnicodeStringArray(const UnicodeString *strings,
                                         int len, int dispose)
 {
     PyObject *list = PyList_New(len);
-    
+
     for (int i = 0; i < len; i++) {
         UnicodeString *u = (UnicodeString *) (strings + i);
         PyList_SET_ITEM(list, i, PyUnicode_FromUnicodeString(u));
@@ -533,7 +605,7 @@ static PyObject *t_dateformatsymbols_getMonths(t_dateformatsymbols *self,
         }
         break;
     }
-            
+
     return PyErr_SetArgsError((PyObject *) self, "getMonths", args);
 }
 
@@ -597,7 +669,7 @@ static PyObject *t_dateformatsymbols_getWeekdays(t_dateformatsymbols *self,
         }
         break;
     }
-            
+
     return PyErr_SetArgsError((PyObject *) self, "getWeekdays", args);
 }
 
@@ -665,8 +737,8 @@ static PyObject *t_dateformatsymbols_setAmPmStrings(t_dateformatsymbols *self,
     return PyErr_SetArgsError((PyObject *) self, "setAmPmStrings", arg);
 }
 
-DEFINE_RICHCMP(DateFormatSymbols, t_dateformatsymbols);
-        
+DEFINE_RICHCMP(DateFormatSymbols, t_dateformatsymbols)
+
 static PyObject *t_dateformatsymbols_getLocalPatternChars(t_dateformatsymbols *self, PyObject *args)
 {
     UnicodeString *u;
@@ -1110,7 +1182,7 @@ static int t_simpledateformat_init(t_simpledateformat *self,
         PyErr_SetArgsError((PyObject *) self, "__init__", args);
         return -1;
     }
-        
+
     if (self->object)
         return 0;
 
@@ -1272,7 +1344,7 @@ static PyObject *t_datetimepatterngenerator_createInstance(PyTypeObject *type,
       default:
         return PyErr_SetArgsError(type, "createInstance", args);
     }
-        
+
     return wrap_DateTimePatternGenerator(dtpg, T_OWNED);
 }
 
@@ -1475,7 +1547,7 @@ static PyObject *t_datetimepatterngenerator_replaceFieldTypes(
 #if U_ICU_VERSION_HEX >= 0x04040000
     int options;
 #endif
-    
+
     switch (PyTuple_Size(args)) {
       case 2:
         if (!parseArgs(args, "SS", &u, &_u, &v, &_v))
@@ -1536,7 +1608,7 @@ static PyObject *t_datetimepatterngenerator_getPatternForSkeleton(
     t_datetimepatterngenerator *self, PyObject *arg)
 {
     UnicodeString *u, _u;;
-    
+
     if (!parseArg(arg, "S", &u, &_u))
     {
         UnicodeString result;
@@ -1552,7 +1624,7 @@ static PyObject *t_datetimepatterngenerator_setDecimal(
     t_datetimepatterngenerator *self, PyObject *arg)
 {
     UnicodeString *u, _u;;
-    
+
     if (!parseArg(arg, "S", &u, &_u))
     {
         self->object->setDecimal(*u);
@@ -1612,11 +1684,11 @@ static PyObject *t_dateinterval_str(t_dateinterval *self)
     DateInterval_format->format(self->object, u, _fp, status);
     if (U_FAILURE(status))
         return ICUException(status).reportError();
-    
+
     return PyUnicode_FromUnicodeString(&u);
 }
 
-DEFINE_RICHCMP(DateInterval, t_dateinterval);
+DEFINE_RICHCMP(DateInterval, t_dateinterval)
 
 
 /* DateIntervalInfo */
@@ -1647,7 +1719,7 @@ static int t_dateintervalinfo_init(t_dateintervalinfo *self,
         PyErr_SetArgsError((PyObject *) self, "__init__", args);
         return -1;
     }
-        
+
     if (self->object)
         return 0;
 
@@ -1673,7 +1745,7 @@ static PyObject *t_dateintervalinfo_setIntervalPattern(t_dateintervalinfo *self,
         STATUS_CALL(self->object->setIntervalPattern(*u0, ucdf, *u1, status));
         Py_RETURN_NONE;
     }
-    
+
     return PyErr_SetArgsError((PyObject *) self, "setIntervalPattern", args);
 }
 
@@ -1702,7 +1774,7 @@ static PyObject *t_dateintervalinfo_getIntervalPattern(t_dateintervalinfo *self,
         }
         break;
     }
-    
+
     return PyErr_SetArgsError((PyObject *) self, "getIntervalPattern", args);
 }
 
@@ -1716,7 +1788,7 @@ static PyObject *t_dateintervalinfo_setFallbackIntervalPattern(t_dateintervalinf
         STATUS_CALL(self->object->setFallbackIntervalPattern(*u, status));
         Py_RETURN_NONE;
     }
-    
+
     return PyErr_SetArgsError((PyObject *) self, "setFallbackIntervalPattern", arg);
 }
 
@@ -1736,11 +1808,11 @@ static PyObject *t_dateintervalinfo_getFallbackIntervalPattern(t_dateintervalinf
         }
         break;
     }
-    
+
     return PyErr_SetArgsError((PyObject *) self, "getFallbackIntervalPattern", args);
 }
 
-DEFINE_RICHCMP(DateIntervalInfo, t_dateintervalinfo);
+DEFINE_RICHCMP(DateIntervalInfo, t_dateintervalinfo)
 
 
 /* DateIntervalFormat */
@@ -1869,9 +1941,45 @@ static PyObject *t_dateintervalformat_createInstance(PyTypeObject *type,
     return PyErr_SetArgsError(type, "createInstance", args);
 }
 
-DEFINE_RICHCMP(DateIntervalFormat, t_dateintervalformat);
+DEFINE_RICHCMP(DateIntervalFormat, t_dateintervalformat)
 
-#endif
+#endif  // ICU >= 4.0
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(64, 0, 0)
+
+static PyObject *t_dateintervalformat_formatToValue(t_dateintervalformat *self,
+                                                     PyObject *args)
+{
+    DateInterval *interval;
+    Calendar *from, *to;
+
+    switch (PyTuple_Size(args)) {
+      case 1:
+        if (!parseArgs(args, "P", TYPE_CLASSID(DateInterval), &interval))
+        {
+            FormattedDateInterval fdi;
+
+            STATUS_CALL(fdi = self->object->formatToValue(*interval, status));
+            return wrap_FormattedDateInterval(fdi);
+        }
+        break;
+      case 2:
+        if (!parseArgs(args, "PP",
+                       TYPE_CLASSID(Calendar), TYPE_CLASSID(Calendar),
+                       &from, &to))
+        {
+            FormattedDateInterval fdi;
+
+            STATUS_CALL(fdi = self->object->formatToValue(*from, *to, status));
+            return wrap_FormattedDateInterval(fdi);
+        }
+        break;
+    }
+
+    return PyErr_SetArgsError((PyObject *) self, "formatToValue", args);
+}
+
+#endif  // ICU >= 64
 
 #if U_ICU_VERSION_HEX >= VERSION_HEX(53, 0, 0)
 
@@ -1885,8 +1993,8 @@ static int t_relativedatetimeformatter_init(t_relativedatetimeformatter *self,
     NumberFormat *number_format;
 #if U_ICU_VERSION_HEX >= VERSION_HEX(54, 0, 0)
     UDateRelativeDateTimeFormatterStyle style;
-#endif
     UDisplayContext context;
+#endif
 
     switch (PyTuple_Size(args)) {
       case 0:
@@ -2008,6 +2116,118 @@ static PyObject *t_relativedatetimeformatter_format(
     return PyErr_SetArgsError((PyObject *) self, "format", args);
 }
 
+#if U_ICU_VERSION_HEX >= VERSION_HEX(57, 0, 0)
+
+static PyObject *t_relativedatetimeformatter_formatNumeric(
+    t_relativedatetimeformatter *self, PyObject *args)
+{
+    URelativeDateTimeUnit unit;
+    UnicodeString *buffer;
+    double offset;
+
+    switch (PyTuple_Size(args)) {
+      case 2:
+        if (!parseArgs(args, "di", &offset, &unit))
+        {
+            UnicodeString result;
+
+            STATUS_CALL(self->object->formatNumeric(
+                offset, unit, result, status));
+            return PyUnicode_FromUnicodeString(&result);
+        }
+        break;
+      case 3:
+        if (!parseArgs(args, "diU", &offset, &unit, &buffer))
+        {
+            STATUS_CALL(self->object->formatNumeric(
+                offset, unit, *buffer, status));
+            Py_RETURN_ARG(args, 2);
+        }
+        break;
+    }
+
+    return PyErr_SetArgsError((PyObject *) self, "formatNumeric", args);
+}
+
+#endif  // ICU >= 57
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(64, 0, 0)
+
+static PyObject *t_relativedatetimeformatter_formatToValue(
+    t_relativedatetimeformatter *self, PyObject *args)
+{
+    UDateDirection direction = UDAT_DIRECTION_PLAIN;
+    UDateAbsoluteUnit abs_unit = UDAT_ABSOLUTE_NOW;
+    UDateRelativeUnit rel_unit = UDAT_RELATIVE_SECONDS;
+    double d;
+
+    switch (PyTuple_Size(args)) {
+      case 0: {
+        FormattedRelativeDateTime value;
+
+        STATUS_CALL(value = self->object->formatToValue(
+            direction, abs_unit, status));
+        return wrap_FormattedRelativeDateTime(value);
+      }
+      case 1:
+        if (!parseArgs(args, "d", &d))
+        {
+            FormattedRelativeDateTime value;
+
+            STATUS_CALL(value = self->object->formatToValue(
+                d, UDAT_DIRECTION_NEXT, rel_unit, status));
+            return wrap_FormattedRelativeDateTime(value);
+        }
+        break;
+      case 2:
+        if (!parseArgs(args, "ii", &direction, &abs_unit))
+        {
+            FormattedRelativeDateTime value;
+
+            STATUS_CALL(value = self->object->formatToValue(
+                direction, abs_unit, status));
+            return wrap_FormattedRelativeDateTime(value);
+        }
+        break;
+      case 3:
+        if (!parseArgs(args, "dii", &d, &direction, &rel_unit))
+        {
+            FormattedRelativeDateTime value;
+
+            STATUS_CALL(value = self->object->formatToValue(
+                d, direction, rel_unit, status));
+            return wrap_FormattedRelativeDateTime(value);
+        }
+        break;
+    }
+
+    return PyErr_SetArgsError((PyObject *) self, "formatToValue", args);
+}
+
+static PyObject *t_relativedatetimeformatter_formatNumericToValue(
+    t_relativedatetimeformatter *self, PyObject *args)
+{
+    URelativeDateTimeUnit unit;
+    double offset;
+
+    switch (PyTuple_Size(args)) {
+      case 2:
+        if (!parseArgs(args, "di", &offset, &unit))
+        {
+            FormattedRelativeDateTime value;
+
+            STATUS_CALL(value = self->object->formatNumericToValue(
+                offset, unit, status));
+            return wrap_FormattedRelativeDateTime(value);
+        }
+        break;
+    }
+
+    return PyErr_SetArgsError((PyObject *) self, "formatNumericToValue", args);
+}
+
+#endif  // ICU >= 64
+
 static PyObject *t_relativedatetimeformatter_combineDateAndTime(
     t_relativedatetimeformatter *self, PyObject *args)
 {
@@ -2045,6 +2265,8 @@ static PyObject *t_relativedatetimeformatter_getNumberFormat(
     return wrap_NumberFormat(const_cast<NumberFormat *>(&format), 0);
 }
 
+#if U_ICU_VERSION_HEX >= VERSION_HEX(54, 0, 0)
+
 static PyObject *t_relativedatetimeformatter_getCapitalizationContext(
     t_relativedatetimeformatter *self)
 {
@@ -2057,7 +2279,9 @@ static PyObject *t_relativedatetimeformatter_getFormatStyle(
     return PyInt_FromLong(self->object->getFormatStyle());
 }
 
-#endif
+#endif  // ICU >= 54
+
+#endif  // ICU >= 53
 
 void _init_dateformat(PyObject *m)
 {
@@ -2096,6 +2320,14 @@ void _init_dateformat(PyObject *m)
     INSTALL_CONSTANTS_TYPE(UDateFormatBooleanAttribute, m);
 #endif
 
+#if U_ICU_VERSION_HEX >= VERSION_HEX(57, 0, 0)
+    INSTALL_CONSTANTS_TYPE(URelativeDateTimeUnit, m);
+#endif
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(64, 0, 0)
+    INSTALL_CONSTANTS_TYPE(URelativeDateTimeFormatterField, m);
+#endif
+
     REGISTER_TYPE(DateFormatSymbols, m);
     INSTALL_TYPE(DateFormat, m);
     REGISTER_TYPE(SimpleDateFormat, m);
@@ -2108,6 +2340,10 @@ void _init_dateformat(PyObject *m)
 #if U_ICU_VERSION_HEX >= VERSION_HEX(53, 0, 0)
     INSTALL_TYPE(RelativeDateTimeFormatter, m);
 #endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(64, 0, 0)
+    INSTALL_STRUCT(FormattedDateInterval, m);
+    INSTALL_STRUCT(FormattedRelativeDateTime, m);
+#endif
 
     INSTALL_STATIC_INT(DateFormatSymbols, FORMAT);
     INSTALL_STATIC_INT(DateFormatSymbols, STANDALONE);
@@ -2282,9 +2518,30 @@ void _init_dateformat(PyObject *m)
 #endif
 
 #if U_ICU_VERSION_HEX >= VERSION_HEX(56, 0, 0)
-    INSTALL_ENUM(UDateFormatBooleanAttribute, "PARSE_PARTIAL_LITERAL_MATCH",
-                 UDAT_PARSE_PARTIAL_LITERAL_MATCH);
-    INSTALL_ENUM(UDateFormatBooleanAttribute, "PARSE_MULTIPLE_PATTERNS_FOR_MATCH",
-                 UDAT_PARSE_MULTIPLE_PATTERNS_FOR_MATCH);
+    INSTALL_ENUM(UDateFormatBooleanAttribute, "PARSE_PARTIAL_LITERAL_MATCH", UDAT_PARSE_PARTIAL_LITERAL_MATCH);
+    INSTALL_ENUM(UDateFormatBooleanAttribute, "PARSE_MULTIPLE_PATTERNS_FOR_MATCH", UDAT_PARSE_MULTIPLE_PATTERNS_FOR_MATCH);
+#endif
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(57, 0, 0)
+    INSTALL_ENUM(URelativeDateTimeUnit, "YEAR", UDAT_REL_UNIT_YEAR);
+    INSTALL_ENUM(URelativeDateTimeUnit, "QUARTER", UDAT_REL_UNIT_QUARTER);
+    INSTALL_ENUM(URelativeDateTimeUnit, "MONTH", UDAT_REL_UNIT_MONTH);
+    INSTALL_ENUM(URelativeDateTimeUnit, "WEEK", UDAT_REL_UNIT_WEEK);
+    INSTALL_ENUM(URelativeDateTimeUnit, "DAY", UDAT_REL_UNIT_DAY);
+    INSTALL_ENUM(URelativeDateTimeUnit, "HOUR", UDAT_REL_UNIT_HOUR);
+    INSTALL_ENUM(URelativeDateTimeUnit, "MINUTE", UDAT_REL_UNIT_MINUTE);
+    INSTALL_ENUM(URelativeDateTimeUnit, "SECOND", UDAT_REL_UNIT_SECOND);
+    INSTALL_ENUM(URelativeDateTimeUnit, "SUNDAY", UDAT_REL_UNIT_SUNDAY);
+    INSTALL_ENUM(URelativeDateTimeUnit, "MONDAY", UDAT_REL_UNIT_MONDAY);
+    INSTALL_ENUM(URelativeDateTimeUnit, "TUESDAY", UDAT_REL_UNIT_TUESDAY);
+    INSTALL_ENUM(URelativeDateTimeUnit, "WEDNESDAY", UDAT_REL_UNIT_WEDNESDAY);
+    INSTALL_ENUM(URelativeDateTimeUnit, "THURSDAY", UDAT_REL_UNIT_THURSDAY);
+    INSTALL_ENUM(URelativeDateTimeUnit, "FRIDAY", UDAT_REL_UNIT_FRIDAY);
+    INSTALL_ENUM(URelativeDateTimeUnit, "SATURDAY", UDAT_REL_UNIT_SATURDAY);
+#endif
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(64, 0, 0)
+    INSTALL_ENUM(URelativeDateTimeFormatterField, "LITERAL_FIELD", UDAT_REL_LITERAL_FIELD);
+    INSTALL_ENUM(URelativeDateTimeFormatterField, "NUMERIC_FIELD", UDAT_REL_NUMERIC_FIELD);
 #endif
 }
