@@ -31,9 +31,9 @@
 #include "script.h"
 #include "macros.h"
 
-DECLARE_CONSTANTS_TYPE(UScriptCode);
+DECLARE_CONSTANTS_TYPE(UScriptCode)
 #if U_ICU_VERSION_HEX >= VERSION_HEX(51, 0, 0)
-DECLARE_CONSTANTS_TYPE(UScriptUsage);
+DECLARE_CONSTANTS_TYPE(UScriptUsage)
 #endif
 
 /* Script */
@@ -87,7 +87,7 @@ static void t_script_dealloc(t_script *self)
     Py_TYPE(self)->tp_free((PyObject *) self);
 }
 
-DECLARE_STRUCT(Script, t_script, UNone, t_script_init, t_script_dealloc);
+DECLARE_STRUCT(Script, t_script, UNone, t_script_init, t_script_dealloc)
 
 
 /* Script */
@@ -572,6 +572,12 @@ void _init_script(PyObject *m)
     INSTALL_ENUM(UScriptCode, "NYIAKENG_PUACHUE_HMONG", USCRIPT_NYIAKENG_PUACHUE_HMONG);
     INSTALL_ENUM(UScriptCode, "WANCHO", USCRIPT_WANCHO);
 #endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(66, 0, 0)
+    INSTALL_ENUM(UScriptCode, "CHORASMIAN", USCRIPT_CHORASMIAN);
+    INSTALL_ENUM(UScriptCode, "DIVES_AKURU", USCRIPT_DIVES_AKURU);
+    INSTALL_ENUM(UScriptCode, "KHITAN_SMALL_SCRIPT", USCRIPT_KHITAN_SMALL_SCRIPT);
+    INSTALL_ENUM(UScriptCode, "YEZIDI", USCRIPT_YEZIDI);
+#endif
 
 #if U_ICU_VERSION_HEX >= VERSION_HEX(51, 0, 0)
     INSTALL_ENUM(UScriptUsage, "NOT_ENCODED", USCRIPT_USAGE_NOT_ENCODED);
